@{
    # Script module or binary module file associated with this manifest.
    # RootModule = ''

    # Version number of this module.
    ModuleVersion         = '3.2.0'

    # ID used to uniquely identify this module
    GUID                  = '15a87fbe-766b-4d2c-b856-645fd4a8d275'

    # Author of this module
    Author                = 'DSC Community'

    # Company or vendor of this module
    CompanyName           = 'DSC Community'

    # Copyright statement for this module
    Copyright             = 'Copyright the DSC Community contributors. All rights reserved.'

    # Description of the functionality provided by this module
    Description           = 'DSC resources for configuring WS-Man.'

    # Minimum version of the Windows PowerShell engine required by this module
    PowerShellVersion     = '4.0'

    # Name of the Windows PowerShell host required by this module
    # PowerShellHostName = ''

    # Minimum version of the Windows PowerShell host required by this module
    # PowerShellHostVersion = ''

    # Minimum version of Microsoft .NET Framework required by this module
    # DotNetFrameworkVersion = ''

    # Minimum version of the common language runtime (CLR) required by this module
    CLRVersion            = '4.0'

    # Processor architecture (None, X86, Amd64) required by this module
    ProcessorArchitecture = 'None'

    # Modules that must be imported into the global environment prior to importing this module
    # RequiredModules = @()

    # Assemblies that must be loaded prior to importing this module
    RequiredAssemblies    = @()

    # Script files (.ps1) that are run in the caller's environment prior to importing this module.
    ScriptsToProcess      = @()

    # Type files (.ps1xml) to be loaded when importing this module
    TypesToProcess        = @()

    # Format files (.ps1xml) to be loaded when importing this module
    FormatsToProcess      = @()

    # Modules to import as nested modules of the module specified in RootModule/ModuleToProcess
    # NestedModules = @()

    # Functions to export from this module
    FunctionsToExport     = @()

    # Cmdlets to export from this module
    CmdletsToExport       = @()

    # Variables to export from this module
    VariablesToExport     = @()

    # Aliases to export from this module
    AliasesToExport       = @()

    # DSC resources to export from this module
    DscResourcesToExport  = @('WSManListener','WSManConfig','WSManServiceConfig')

    # List of all modules packaged with this module
    # ModuleList = @()

    # List of all files packaged with this module
    FileList              = @()

    # Private data to pass to the module specified in RootModule/ModuleToProcess. This may also contain a PSData hashtable with additional module metadata used by PowerShell.
    PrivateData           = @{

        PSData = @{
            # Set to a prerelease string value if the release should be a prerelease.
            Prerelease   = ''

            # Tags applied to this module. These help with module discovery in online galleries.
            Tags         = @('DesiredStateConfiguration', 'DSC', 'DSCResource', 'WSMan')

            # A URL to the license for this module.
            LicenseUri   = 'https://github.com/dsccommunity/WSManDsc/blob/main/LICENSE'

            # A URL to the main website for this project.
            ProjectUri   = 'https://github.com/dsccommunity/WSManDsc'

            # A URL to an icon representing this module.
            IconUri      = 'https://dsccommunity.org/images/DSC_Logo_300p.png'

            # ReleaseNotes of this module
            ReleaseNotes = '## [3.2.0] - 2025-01-19

### Added

- Added build task `Generate_Conceptual_Help` to generate conceptual help
  for the DSC resource.
- Added build task `Generate_Wiki_Content` to generate the wiki content
  that can be used to update the GitHub Wiki.

### Changed

- Updated CI pipeline files.
- No longer run integration tests when running the build task `test`, e.g.
  `.\build.ps1 -Task test`. To manually run integration tests, run the
  following:
  ```powershell
  .\build.ps1 -Tasks test -PesterScript ''tests/Integration'' -CodeCoverageThreshold 0
  ```
- Change Azure DevOps Pipeline definition to include `source/*` - fixes [Issue #75](https://github.com/dsccommunity/WSManDsc/issues/75).
- Updated pipeline to use `latest` version of `ModuleBuilder` - fixes [Issue #75](https://github.com/dsccommunity/WSManDsc/issues/75).
- Merge `HISTORIC_CHANGELOG.md` into `CHANGELOG.md` - fixes [Issue #76](https://github.com/dsccommunity/WSManDsc/issues/76).
- WSManDsc
  - Updated to use the common module _DscResource.Common_ - Fixes [Issue #78](https://github.com/dsccommunity/WSManDsc/issues/78).
  - Fixed build failures caused by changes in `ModuleBuilder` module v1.7.0
    by changing `CopyDirectories` to `CopyPaths` - Fixes [Issue #79](https://github.com/dsccommunity/WSManDsc/issues/79).
  - Pin `Pester` module to 4.10.1 because Pester 5.0 is missing code
    coverage - Fixes [Issue #78](https://github.com/dsccommunity/WSManDsc/issues/78).
  - Automatically publish documentation to GitHub Wiki - Fixes [Issue #82](https://github.com/dsccommunity/WSManDsc/issues/82).
  - Fix build pipeline so it uses the build image `windows-latest`.
- Renamed `master` branch to `main` - Fixes [Issue #82](https://github.com/dsccommunity/WSManDsc/issues/82).
- Minor corrections to pipeline files and examples after renaming `master`
  branch to `main`.
- Updated `GitVersion.yml` to latest pattern - Fixes [Issue #87](https://github.com/dsccommunity/WSManDsc/issues/87).
- Updated build to use `Sampler.GitHubTasks` - Fixes [Issue #90](https://github.com/dsccommunity/WSManDsc/issues/90).
- Added support for publishing code coverage to `CodeCov.io` and
  Azure Pipelines - Fixes [Issue #91](https://github.com/dsccommunity/WSManDsc/issues/91).
- Build pipeline: Removed unused `dscBuildVariable` tasks.
- Updated .github issue templates to standard - Fixes [Issue #97](https://github.com/dsccommunity/WSManDsc/issues/97).
- Added Create_ChangeLog_GitHub_PR task to publish stage of build pipeline.
- Added SECURITY.md.
- Updated pipeline Deploy_Module anb Code_Coverage jobs to use ubuntu-latest
  images - Fixes [Issue #96](https://github.com/dsccommunity/WSManDsc/issues/96).
- Updated pipeline unit tests and integration tests to use Windows Server 2019 and
  Windows Server 2022 images - Fixes [Issue #96](https://github.com/dsccommunity/WSManDsc/issues/96).
- CI Pipeline
  - Updated pipeline files to match current DSC Community patterns - fixes [Issue #103](https://github.com/dsccommunity/WSManDsc/issues/103).
  - Updated HQRM and build steps to use windows-latest image.
  - Pin gitversion to V5.
- WSManDsc
  - Added support for changing the hostname and/or certificate thumbprint on the listener fixes [Issue #23](https://github.com/dsccommunity/WSManDsc/issues/23).
  - Converted tests to Pester 5 - fixes [#99](https://github.com/dsccommunity/WSManDsc/issues/99).
- `DSC_WSManConfig`
  - Refactor `Test-TargetResource` to use `Test-DscParameterState`.
  - Remove unused strings.
- `DSC_WSManServiceConfig`
  - Refactor `Test-TargetResource` to use `Test-DscParameterState`.
  - Remove unused strings

### Fixed

- Fixed pipeline by replacing the GitVersion task in the `azure-pipelines.yml`
  with a script.

'
        } # End of PSData hashtable

    } # End of PrivateData hashtable

    # HelpInfo URI of this module
    # HelpInfoURI = ''

    # Default prefix for commands exported from this module. Override the default prefix using Import-Module -Prefix.
    # DefaultCommandPrefix = ''
}
